==> tipfy.ext.session-0.6.1.zip: tipfy.ext.session-0.6.1/setup.py <==
"""
tipfy.ext.session
=================

This extension implements sessions using datastore, memcache or secure cookies
for Tipfy, a framework made for Google App Engine.

It also provides an interface to get and set flash messages and to set and
delete secure cookies or ordinary cookies, and several convenient
session-related mixins for the RequestHandler.

Documentation is available at
`http://www.tipfy.org/wiki/extensions/session/ <http://www.tipfy.org/wiki/extensions/session/>`_.

Links
-----
* `Tipfy's website <http://www.tipfy.org/>`_
* `API Documentation <http://www.tipfy.org/docs/>`_
* `Wiki <http://www.tipfy.org/wiki/>`_
* `Discussion Group <http://groups.google.com/group/tipfy>`_
* `Issue Tracker <http://code.google.com/p/tipfy/issues/list>`_
* `Repository <http://code.google.com/p/tipfy/>`_
"""
from setuptools import setup

setup(
    name = 'tipfy.ext.session',
    version = '0.6.1',
    license = 'BSD',
    url = 'http://www.tipfy.org/',
    description = 'Session extension for tipfy',
    long_description = __doc__,
    author = 'Rodrigo Moraes',
    author_email = 'rodrigo.moraes@gmail.com',
    zip_safe = False,
    platforms='any',
    packages = [
        'tipfy',
        'tipfy.ext',
    ],
    namespace_packages = [
        'tipfy',
        'tipfy.ext',
    ],
    include_package_data = True,
    install_requires = [
        'tipfy',
        'tipfy.ext.db',
    ],
    classifiers = [
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ]
)

==> tipfy.ext.session-0.6.2.zip: tipfy.ext.session-0.6.2/setup.py <==
"""
tipfy.ext.session
=================

This extension implements sessions using datastore, memcache or secure cookies
for `tipfy <http://www.tipfy.org/>`_.

It also provides an interface to get and set flash messages and to set and
delete secure cookies or ordinary cookies, and several convenient
session-related mixins for the RequestHandler.

Links
-----
* `Documentation <http://www.tipfy.org/wiki/extensions/session/>`_
* `Source Code Repository <http://code.google.com/p/tipfy-ext-session/>`_
* `Issue Tracker <http://code.google.com/p/tipfy-ext-session/issues/list>`_

About tipfy
-----------
* `Home page <http://www.tipfy.org/>`_
* `Extension list <http://www.tipfy.org/wiki/extensions/>`_
* `Discussion Group <http://groups.google.com/group/tipfy>`_
"""
from setuptools import setup

setup(
    name = 'tipfy.ext.session',
    version = '0.6.2',
    license = 'BSD',
    url = 'http://www.tipfy.org/',
    description = 'Session extension for tipfy',
    long_description = __doc__,
    author = 'Rodrigo Moraes',
    author_email = 'rodrigo.moraes@gmail.com',
    zip_safe = False,
    platforms='any',
    packages = [
        'tipfy',
        'tipfy.ext',
    ],
    namespace_packages = [
        'tipfy',
        'tipfy.ext',
    ],
    include_package_data = True,
    install_requires = [
        'tipfy',
        'tipfy.ext.db',
    ],
    classifiers = [
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ]
)
